import numpy as np
import xgboost
from typing import List, Tuple

def compute_mean(values: List):
    return round(np.mean(values)*100, 3)

def compute_std(values: List):
    return round(np.std(values), 3)

def gini_xgb(preds: np.array, dtrain: xgboost.core.DMatrix) -> List[Tuple]:
    labels = dtrain.get_label()
    gini_score = -eval_gini(labels, preds)
    return [('gini', gini_score)]

def eval_gini(y_true: np.array, y_prob: np.array) -> float:
    y_true = np.asarray(y_true)
    y_true = y_true[np.argsort(y_prob)]
    ntrue = 0
    gini = 0
    delta = 0
    n = len(y_true)
    for i in range(n-1, -1, -1):
        y_i = y_true[i]
        ntrue += y_i
        gini += y_i * delta
        delta += 1 - y_i
    gini = 1 - 2 * gini / (ntrue * (n - ntrue))
    return gini