import {Module} from "vuex";
import {ArgumentItem, ArgumentType} from "@/model/ArgumentItem";

const argumentStore: Module<any, any> = {
    state: {
        arguments: [
            new ArgumentItem(ArgumentType.Gender, "Personen er en mand"),
            new ArgumentItem(ArgumentType.BirthYear, "Personen har en alder på 50 år"),
            new ArgumentItem(ArgumentType.LoanPeriod, "Den gennemsnitlige låneperiode for alle hjælpemidler er 150 dage"),
            new ArgumentItem(ArgumentType.NumberAts, "Det samlede antal hjælpemidler er 7"),
        ],
    },
    mutations: {
        SHAP_GENDER_COMPLETE(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.Gender).positiveComplete = value >= 0
        },
        SHAP_BIRTH_YEAR_COMPLETE(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.BirthYear).positiveComplete = value >= 0
        },
        SHAP_LOAN_PERIOD_COMPLETE(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.LoanPeriod).positiveComplete = value >= 0
        },
        SHAP_NUMBER_ATS_COMPLETE(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.NumberAts).positiveComplete = value >= 0
        },
        SHAP_GENDER_FALL(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.Gender).positiveFall = value >= 0
        },
        SHAP_BIRTH_YEAR_FALL(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.BirthYear).positiveFall = value >= 0
        },
        SHAP_LOAN_PERIOD_FALL(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.LoanPeriod).positiveFall = value >= 0
        },
        SHAP_NUMBER_ATS_FALL(state, value) {
            state.arguments.find((x: { type: ArgumentType; }) => x.type === ArgumentType.NumberAts).positiveFall = value >= 0
        },
    },
    actions: {
        shapArgumentsComplete({commit, state}, value) {
            commit('SHAP_GENDER_COMPLETE', value.Gender)
            commit('SHAP_BIRTH_YEAR_COMPLETE', value.BirthYear)
            commit('SHAP_LOAN_PERIOD_COMPLETE', value.LoanPeriod)
            commit('SHAP_NUMBER_ATS_COMPLETE', value.NumberAts)
        },
        shapArgumentsFall({commit, state}, value) {
            commit('SHAP_GENDER_FALL', value.Gender)
            commit('SHAP_BIRTH_YEAR_FALL', value.BirthYear)
            commit('SHAP_LOAN_PERIOD_FALL', value.LoanPeriod)
            commit('SHAP_NUMBER_ATS_FALL', value.NumberAts)
        },
    },
    getters: {
        positiveArgumentsComplete: function (state): ArgumentItem[] {
            return state.arguments.filter((x: { positiveComplete: any; }) => x.positiveComplete)
        },
        positiveArgumentsFall: function (state): ArgumentItem[] {
            return state.arguments.filter((x: { positiveFall: boolean; }) => x.positiveFall)
        },
        negativeArgumentsComplete: function (state): ArgumentItem[] {
            return state.arguments.filter((x: { positiveComplete: boolean; }) => !x.positiveComplete)
        },
        negativeArgumentsFall: function (state): ArgumentItem[] {
            return state.arguments.filter((x: { positiveFall: boolean; }) => !x.positiveFall)
        },
    }
}

export default argumentStore
